package com.zehong.system.mapper;

import java.util.List;
import com.zehong.system.domain.TWorkTaskMember;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author zehong
 * @date 2023-09-15
 */
public interface TWorkTaskMemberMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public TWorkTaskMember selectTWorkTaskMemberById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tWorkTaskMember 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TWorkTaskMember> selectTWorkTaskMemberList(TWorkTaskMember tWorkTaskMember);

    /**
     * 新增【请填写功能名称】
     * 
     * @param tWorkTaskMember 【请填写功能名称】
     * @return 结果
     */
    public int insertTWorkTaskMember(TWorkTaskMember tWorkTaskMember);

    /**
     * 修改【请填写功能名称】
     * 
     * @param tWorkTaskMember 【请填写功能名称】
     * @return 结果
     */
    public int updateTWorkTaskMember(TWorkTaskMember tWorkTaskMember);
    public int updateByMemberIdTaskId(TWorkTaskMember tWorkTaskMember);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteTWorkTaskMemberById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTWorkTaskMemberByIds(Long[] ids);

    /**
     * 根据任务主键删除人
     * @param taskId 任务主键
     * @return
     */
    int deleteWorkTaskMemberByTaskId(long taskId);
}
